You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@jmeter.apache.org by Vladimir Sitnikov <si...@gmail.com> on 2022/03/14 12:40:46 UTC

Slow "view results in tree" in 5.5 with Java11 (was [VOTE] Release JMeter 5.5 RC1)

>When i clique to display the resultat data (html boy) the JMeter is
>very slow to show the page.
>I need to wait 4 sec to 8 sec between click and the http sampler and
>the display in text format.

Vincent, do you think you could create a reproducer for the issue? (e.g.
share HTML contents)
Do you think you could gather thread dumps (e.g. jstack <jmeter_pid>) while
clicking the "view results" tab?

Vladimir

Re: Slow "view results in tree" in 5.5 with Java11 (was [VOTE] Release JMeter 5.5 RC1)

Posted by Vincent Daburon <vd...@gmail.com>.
Hi,
When i need to switch quickly the JDK used by JMeter i set in the
jmeter.bat with :

setlocal
set *JM_LAUNCH*=C:\Java\jdk1.8.0_191\bin\java.exe
rem set JM_LAUNCH=C:\Java\openjdk-11u-11.0.4_11\bin\java.exe
rem set JM_LAUNCH=C:\Java\jdk-11.0.2\bin\java.exe
rem set JM_LAUNCH=C:\Java\jdk-17.0.2\bin\java.exe

and remplace *java *with %JM_LAUNCH%
for /f "tokens=3" %%g in ('%*JM_LAUNCH*% -version 2^>^&1 ^| findstr /i
"version"') do (

Regards.
Vincent DABURON


Le lun. 14 mars 2022 à 15:11, Vincent Daburon <vd...@gmail.com> a écrit :

> Hi,
> I change the real host to a host1anony
>
> The JTL file with html trouble display in the View Tree Result and JDK
> 11 but i record with JDK 8 in attachment.
>
> Regards.
> Vincent DABURON
>
> Le lun. 14 mars 2022 à 15:07, Felix Schumacher
> <fe...@internetallee.de> a écrit :
> >
> > This slowness happens on Windows 10 with Java 11 and OpenJDK 8 (282),
> > whenever I switch from an "empty" sample to a "biggish" sample.
> > Switching from a "biggish" sample to another "biggish" sample has no
> > real performance impact (below 1 second, I would say).
> >
> > Will try with Linux later.
> >
> > Felix
> >
> > Am 14.03.2022 14:51, schrieb Felix Schumacher:
> > > I think I can reproduce it. I sampled a biggish page. It recorded
> > > three sub samples. Two redirects and the actual page.
> > > Clicking on the main sample takes one or two seconds. Changing to the
> > > redirect is fast, but changing back to the main sample or the sub
> > > sample with the page is incredibly slow.
> > >
> > > Gui is not responding, as the awt thread is calculating the preferred
> > > view size and is almost all the time in
> > > sun.font.SunLayoutEngine.shape.
> > >
> > > Felix
> > >
> > > Am 14. März 2022 13:40:46 MEZ schrieb Vladimir Sitnikov
> > > <si...@gmail.com>:
> > >>> When i clique to display the resultat data (html boy) the JMeter is
> > >>> very slow to show the page.
> > >>> I need to wait 4 sec to 8 sec between click and the http sampler and
> > >>> the display in text format.
> > >>
> > >> Vincent, do you think you could create a reproducer for the issue?
> > >> (e.g.
> > >> share HTML contents)
> > >> Do you think you could gather thread dumps (e.g. jstack <jmeter_pid>)
> > >> while
> > >> clicking the "view results" tab?
> > >>
> > >> Vladimir
>

Re: Slow "view results in tree" in 5.5 with Java11 (was [VOTE] Release JMeter 5.5 RC1)

Posted by Vincent Daburon <vd...@gmail.com>.
Hi,
text.kerning.max_document_size=1
Yes the display is very responsive and i don't notice any delay in the View
Results Tree for smal html page

java.runtime.version=11.0.4+11

Regards.
Vincent DABURON


Le lun. 14 mars 2022 à 15:33, Vladimir Sitnikov <si...@gmail.com>
a écrit :

> Could you please try if text.kerning.max_document_size=1 in
> jmeter.properties solves the issue?
>
> Vladimir
>

Re: Slow "view results in tree" in 5.5 with Java11 (was [VOTE] Release JMeter 5.5 RC1)

Posted by Vladimir Sitnikov <si...@gmail.com>.
Could you please try if text.kerning.max_document_size=1 in
jmeter.properties solves the issue?

Vladimir

Re: Slow "view results in tree" in 5.5 with Java11 (was [VOTE] Release JMeter 5.5 RC1)

Posted by Vincent Daburon <vd...@gmail.com>.
Hi,
More context.
I use the *Windows *LAF not the Darklaf

And i am adminstrator => the LAF is save
I *don't *have

java.util.prefs.WindowsPreferences
WARNING: Could not open/create prefs root node Software\JavaSoft\Prefs at root 0
x80000002. Windows RegCreateKeyEx(…) returned error code 5.



Le lun. 14 mars 2022 à 15:11, Vincent Daburon <vd...@gmail.com> a écrit :

> Hi,
> I change the real host to a host1anony
>
> The JTL file with html trouble display in the View Tree Result and JDK
> 11 but i record with JDK 8 in attachment.
>
> Regards.
> Vincent DABURON
>
> Le lun. 14 mars 2022 à 15:07, Felix Schumacher
> <fe...@internetallee.de> a écrit :
> >
> > This slowness happens on Windows 10 with Java 11 and OpenJDK 8 (282),
> > whenever I switch from an "empty" sample to a "biggish" sample.
> > Switching from a "biggish" sample to another "biggish" sample has no
> > real performance impact (below 1 second, I would say).
> >
> > Will try with Linux later.
> >
> > Felix
> >
> > Am 14.03.2022 14:51, schrieb Felix Schumacher:
> > > I think I can reproduce it. I sampled a biggish page. It recorded
> > > three sub samples. Two redirects and the actual page.
> > > Clicking on the main sample takes one or two seconds. Changing to the
> > > redirect is fast, but changing back to the main sample or the sub
> > > sample with the page is incredibly slow.
> > >
> > > Gui is not responding, as the awt thread is calculating the preferred
> > > view size and is almost all the time in
> > > sun.font.SunLayoutEngine.shape.
> > >
> > > Felix
> > >
> > > Am 14. März 2022 13:40:46 MEZ schrieb Vladimir Sitnikov
> > > <si...@gmail.com>:
> > >>> When i clique to display the resultat data (html boy) the JMeter is
> > >>> very slow to show the page.
> > >>> I need to wait 4 sec to 8 sec between click and the http sampler and
> > >>> the display in text format.
> > >>
> > >> Vincent, do you think you could create a reproducer for the issue?
> > >> (e.g.
> > >> share HTML contents)
> > >> Do you think you could gather thread dumps (e.g. jstack <jmeter_pid>)
> > >> while
> > >> clicking the "view results" tab?
> > >>
> > >> Vladimir
>

Re: Slow "view results in tree" in 5.5 with Java11 (was [VOTE] Release JMeter 5.5 RC1)

Posted by Vincent Daburon <vd...@gmail.com>.
Hi,
I change the real host to a host1anony

The JTL file with html trouble display in the View Tree Result and JDK
11 but i record with JDK 8 in attachment.

Regards.
Vincent DABURON

Le lun. 14 mars 2022 à 15:07, Felix Schumacher
<fe...@internetallee.de> a écrit :
>
> This slowness happens on Windows 10 with Java 11 and OpenJDK 8 (282),
> whenever I switch from an "empty" sample to a "biggish" sample.
> Switching from a "biggish" sample to another "biggish" sample has no
> real performance impact (below 1 second, I would say).
>
> Will try with Linux later.
>
> Felix
>
> Am 14.03.2022 14:51, schrieb Felix Schumacher:
> > I think I can reproduce it. I sampled a biggish page. It recorded
> > three sub samples. Two redirects and the actual page.
> > Clicking on the main sample takes one or two seconds. Changing to the
> > redirect is fast, but changing back to the main sample or the sub
> > sample with the page is incredibly slow.
> >
> > Gui is not responding, as the awt thread is calculating the preferred
> > view size and is almost all the time in
> > sun.font.SunLayoutEngine.shape.
> >
> > Felix
> >
> > Am 14. März 2022 13:40:46 MEZ schrieb Vladimir Sitnikov
> > <si...@gmail.com>:
> >>> When i clique to display the resultat data (html boy) the JMeter is
> >>> very slow to show the page.
> >>> I need to wait 4 sec to 8 sec between click and the http sampler and
> >>> the display in text format.
> >>
> >> Vincent, do you think you could create a reproducer for the issue?
> >> (e.g.
> >> share HTML contents)
> >> Do you think you could gather thread dumps (e.g. jstack <jmeter_pid>)
> >> while
> >> clicking the "view results" tab?
> >>
> >> Vladimir

Re: Slow "view results in tree" in 5.5 with Java11 (was [VOTE] Release JMeter 5.5 RC1)

Posted by Felix Schumacher <fe...@internetallee.de>.
On Linux a delay is noticeable, when switching from empty to biggish, 
but seems only like 1 to 2 seconds.

Tested with an old Oracle JDK and OpenJDK 8, 11 and 17.

Felix

Am 14.03.22 um 15:07 schrieb Felix Schumacher:
> This slowness happens on Windows 10 with Java 11 and OpenJDK 8 (282), 
> whenever I switch from an "empty" sample to a "biggish" sample. 
> Switching from a "biggish" sample to another "biggish" sample has no 
> real performance impact (below 1 second, I would say).
>
> Will try with Linux later.
>
> Felix
>
> Am 14.03.2022 14:51, schrieb Felix Schumacher:
>> I think I can reproduce it. I sampled a biggish page. It recorded
>> three sub samples. Two redirects and the actual page.
>> Clicking on the main sample takes one or two seconds. Changing to the
>> redirect is fast, but changing back to the main sample or the sub
>> sample with the page is incredibly slow.
>>
>> Gui is not responding, as the awt thread is calculating the preferred
>> view size and is almost all the time in
>> sun.font.SunLayoutEngine.shape.
>>
>> Felix
>>
>> Am 14. März 2022 13:40:46 MEZ schrieb Vladimir Sitnikov
>> <si...@gmail.com>:
>>>> When i clique to display the resultat data (html boy) the JMeter is
>>>> very slow to show the page.
>>>> I need to wait 4 sec to 8 sec between click and the http sampler and
>>>> the display in text format.
>>>
>>> Vincent, do you think you could create a reproducer for the issue? 
>>> (e.g.
>>> share HTML contents)
>>> Do you think you could gather thread dumps (e.g. jstack 
>>> <jmeter_pid>) while
>>> clicking the "view results" tab?
>>>
>>> Vladimir

Re: Slow "view results in tree" in 5.5 with Java11 (was [VOTE] Release JMeter 5.5 RC1)

Posted by Felix Schumacher <fe...@internetallee.de>.
This slowness happens on Windows 10 with Java 11 and OpenJDK 8 (282), 
whenever I switch from an "empty" sample to a "biggish" sample. 
Switching from a "biggish" sample to another "biggish" sample has no 
real performance impact (below 1 second, I would say).

Will try with Linux later.

Felix

Am 14.03.2022 14:51, schrieb Felix Schumacher:
> I think I can reproduce it. I sampled a biggish page. It recorded
> three sub samples. Two redirects and the actual page.
> Clicking on the main sample takes one or two seconds. Changing to the
> redirect is fast, but changing back to the main sample or the sub
> sample with the page is incredibly slow.
> 
> Gui is not responding, as the awt thread is calculating the preferred
> view size and is almost all the time in
> sun.font.SunLayoutEngine.shape.
> 
> Felix
> 
> Am 14. März 2022 13:40:46 MEZ schrieb Vladimir Sitnikov
> <si...@gmail.com>:
>>> When i clique to display the resultat data (html boy) the JMeter is
>>> very slow to show the page.
>>> I need to wait 4 sec to 8 sec between click and the http sampler and
>>> the display in text format.
>> 
>> Vincent, do you think you could create a reproducer for the issue? 
>> (e.g.
>> share HTML contents)
>> Do you think you could gather thread dumps (e.g. jstack <jmeter_pid>) 
>> while
>> clicking the "view results" tab?
>> 
>> Vladimir

Re: Slow "view results in tree" in 5.5 with Java11 (was [VOTE] Release JMeter 5.5 RC1)

Posted by Felix Schumacher <fe...@internetallee.de>.
Am 16.03.22 um 09:04 schrieb Vladimir Sitnikov:
> Felix, thank you.
>
> I went over the stacktrace and found an interesting case:
>
> 8231084: Large performance regression in SwingMark TextArea in 14-b13
> https://github.com/openjdk/jdk/commit/007a0fb2321f1691d341a3ceb9d321cd01d506c8
> https://mail.openjdk.java.net/pipermail/swing-dev/2019-November/009850.html
>
> I'm not sure it is the same issue we are running into.

I am not sure, as it happens on JDK 8 and it doesn't throw errors or 
compute wrong sizes, but is "just" slow.

Felix

>
> Vladimir
>

Re: Slow "view results in tree" in 5.5 with Java11 (was [VOTE] Release JMeter 5.5 RC1)

Posted by Vladimir Sitnikov <si...@gmail.com>.
Felix, thank you.

I went over the stacktrace and found an interesting case:

8231084: Large performance regression in SwingMark TextArea in 14-b13
https://github.com/openjdk/jdk/commit/007a0fb2321f1691d341a3ceb9d321cd01d506c8
https://mail.openjdk.java.net/pipermail/swing-dev/2019-November/009850.html

I'm not sure it is the same issue we are running into.

Vladimir

Re: Slow "view results in tree" in 5.5 with Java11 (was [VOTE] Release JMeter 5.5 RC1)

Posted by Felix Schumacher <fe...@internetallee.de>.
Am 14.03.2022 14:51, schrieb Felix Schumacher:
> I think I can reproduce it. I sampled a biggish page. It recorded
> three sub samples. Two redirects and the actual page.
> Clicking on the main sample takes one or two seconds. Changing to the
> redirect is fast, but changing back to the main sample or the sub
> sample with the page is incredibly slow.
> 
> Gui is not responding, as the awt thread is calculating the preferred
> view size and is almost all the time in
> sun.font.SunLayoutEngine.shape.

Stacktrace is:

"AWT-EventQueue-0" #19 prio=6 os_prio=0 cpu=1196937.50ms 
elapsed=1688.37s tid=0x00000207187f4800 nid=0x344c runnable  
[0x000000b8f4efa000]
    java.lang.Thread.State: RUNNABLE
	at sun.font.SunLayoutEngine.shape(java.desktop@11/Native Method)
	at 
sun.font.SunLayoutEngine.layout(java.desktop@11/SunLayoutEngine.java:176)
	at 
sun.font.GlyphLayout$EngineRecord.layout(java.desktop@11/GlyphLayout.java:687)
	at sun.font.GlyphLayout.layout(java.desktop@11/GlyphLayout.java:468)
	at 
sun.font.ExtendedTextSourceLabel.createGV(java.desktop@11/ExtendedTextSourceLabel.java:329)
	at 
sun.font.ExtendedTextSourceLabel.getGV(java.desktop@11/ExtendedTextSourceLabel.java:315)
	at 
sun.font.ExtendedTextSourceLabel.createLogicalBounds(java.desktop@11/ExtendedTextSourceLabel.java:225)
	at 
sun.font.ExtendedTextSourceLabel.getAdvance(java.desktop@11/ExtendedTextSourceLabel.java:134)
	at java.awt.font.TextLine.init(java.desktop@11/TextLine.java:281)
	at java.awt.font.TextLine.<init>(java.desktop@11/TextLine.java:129)
	at 
java.awt.font.TextLine.fastCreateTextLine(java.desktop@11/TextLine.java:978)
	at 
java.awt.font.TextLayout.fastInit(java.desktop@11/TextLayout.java:611)
	at java.awt.font.TextLayout.<init>(java.desktop@11/TextLayout.java:392)
	at java.awt.Font.getStringBounds(java.desktop@11/Font.java:2612)
	at 
sun.swing.SwingUtilities2.getFontCharsWidth(java.desktop@11/SwingUtilities2.java:946)
	at 
sun.swing.SwingUtilities2.getFontCharWidth(java.desktop@11/SwingUtilities2.java:934)
	at 
javax.swing.text.Utilities.getTabbedTextOffset(java.desktop@11/Utilities.java:529)
	at 
javax.swing.text.Utilities.getTabbedTextOffset(java.desktop@11/Utilities.java:458)
	at 
javax.swing.text.WrappedPlainView.calculateBreakPosition(java.desktop@11/WrappedPlainView.java:366)
	at 
javax.swing.text.WrappedPlainView$WrappedLine.breakLines(java.desktop@11/WrappedPlainView.java:920)
	at 
javax.swing.text.WrappedPlainView$WrappedLine.getPreferredSpan(java.desktop@11/WrappedPlainView.java:692)
	at javax.swing.text.View.getMaximumSpan(java.desktop@11/View.java:267)
	at 
javax.swing.text.BoxView.calculateMajorAxisRequirements(java.desktop@11/BoxView.java:874)
	at 
javax.swing.text.BoxView.checkRequests(java.desktop@11/BoxView.java:931)
	at 
javax.swing.text.BoxView.setSpanOnAxis(java.desktop@11/BoxView.java:330)
	at javax.swing.text.BoxView.layout(java.desktop@11/BoxView.java:710)
	at javax.swing.text.BoxView.setSize(java.desktop@11/BoxView.java:398)
	at 
javax.swing.text.WrappedPlainView.setSize(java.desktop@11/WrappedPlainView.java:519)
	at 
javax.swing.plaf.basic.BasicTextUI$RootView.setSize(java.desktop@11/BasicTextUI.java:1821)
	at 
javax.swing.plaf.basic.BasicTextUI.getPreferredSize(java.desktop@11/BasicTextUI.java:948)
	at 
com.github.weisj.darklaf.ui.text.DarkTextUI.getPreferredSize(DarkTextUI.java:223)
	at 
javax.swing.JComponent.getPreferredSize(java.desktop@11/JComponent.java:1680)
	at 
javax.swing.JEditorPane.getPreferredSize(java.desktop@11/JEditorPane.java:1345)
	at 
javax.swing.JViewport.getViewSize(java.desktop@11/JViewport.java:1119)
	at 
javax.swing.plaf.basic.BasicScrollPaneUI.syncScrollPaneWithViewport(java.desktop@11/BasicScrollPaneUI.java:330)
	at 
javax.swing.plaf.basic.BasicScrollPaneUI$Handler.stateChanged(java.desktop@11/BasicScrollPaneUI.java:1126)
	at 
javax.swing.JViewport.fireStateChanged(java.desktop@11/JViewport.java:1490)
	at javax.swing.JViewport.setView(java.desktop@11/JViewport.java:1089)
	at 
javax.swing.JScrollPane.setViewportView(java.desktop@11/JScrollPane.java:980)
	at 
org.apache.jmeter.visualizers.RenderAsText.showTextResponse(RenderAsText.java:36)
	at 
org.apache.jmeter.visualizers.RenderAsText.renderResult(RenderAsText.java:29)
	at 
org.apache.jmeter.visualizers.ViewResultsFullVisualizer.valueChanged(ViewResultsFullVisualizer.java:400)
	at 
org.apache.jmeter.visualizers.ViewResultsFullVisualizer.valueChanged(ViewResultsFullVisualizer.java:373)
	at javax.swing.JTree.fireValueChanged(java.desktop@11/JTree.java:2967)
	at 
javax.swing.JTree$TreeSelectionRedirector.valueChanged(java.desktop@11/JTree.java:3456)
	at 
javax.swing.tree.DefaultTreeSelectionModel.fireValueChanged(java.desktop@11/DefaultTreeSelectionModel.java:641)
	at 
javax.swing.tree.DefaultTreeSelectionModel.notifyPathChange(java.desktop@11/DefaultTreeSelectionModel.java:1111)
	at 
javax.swing.tree.DefaultTreeSelectionModel.setSelectionPaths(java.desktop@11/DefaultTreeSelectionModel.java:297)
	at 
javax.swing.tree.DefaultTreeSelectionModel.setSelectionPath(java.desktop@11/DefaultTreeSelectionModel.java:191)
	at javax.swing.JTree.setSelectionPath(java.desktop@11/JTree.java:1656)
	at 
javax.swing.plaf.basic.BasicTreeUI.selectPathForEvent(java.desktop@11/BasicTreeUI.java:2736)
	at 
javax.swing.plaf.basic.BasicTreeUI$Handler.handleSelection(java.desktop@11/BasicTreeUI.java:4016)
	at 
javax.swing.plaf.basic.BasicTreeUI$Handler.mousePressed(java.desktop@11/BasicTreeUI.java:3955)
	at 
java.awt.AWTEventMulticaster.mousePressed(java.desktop@11/AWTEventMulticaster.java:287)
	at 
java.awt.Component.processMouseEvent(java.desktop@11/Component.java:6629)
	at 
javax.swing.JComponent.processMouseEvent(java.desktop@11/JComponent.java:3342)
	at java.awt.Component.processEvent(java.desktop@11/Component.java:6397)
	at java.awt.Container.processEvent(java.desktop@11/Container.java:2263)
	at 
java.awt.Component.dispatchEventImpl(java.desktop@11/Component.java:5008)
	at 
java.awt.Container.dispatchEventImpl(java.desktop@11/Container.java:2321)
	at 
java.awt.Component.dispatchEvent(java.desktop@11/Component.java:4840)
	at 
java.awt.LightweightDispatcher.retargetMouseEvent(java.desktop@11/Container.java:4918)
	at 
java.awt.LightweightDispatcher.processMouseEvent(java.desktop@11/Container.java:4544)
	at 
java.awt.LightweightDispatcher.dispatchEvent(java.desktop@11/Container.java:4488)
	at 
java.awt.Container.dispatchEventImpl(java.desktop@11/Container.java:2307)
	at java.awt.Window.dispatchEventImpl(java.desktop@11/Window.java:2772)
	at 
java.awt.Component.dispatchEvent(java.desktop@11/Component.java:4840)
	at 
java.awt.EventQueue.dispatchEventImpl(java.desktop@11/EventQueue.java:772)
	at java.awt.EventQueue$4.run(java.desktop@11/EventQueue.java:721)
	at java.awt.EventQueue$4.run(java.desktop@11/EventQueue.java:715)
	at java.security.AccessController.doPrivileged(java.base@11/Native 
Method)
	at 
java.security.ProtectionDomain$JavaSecurityAccessImpl.doIntersectionPrivilege(java.base@11/ProtectionDomain.java:85)
	at 
java.security.ProtectionDomain$JavaSecurityAccessImpl.doIntersectionPrivilege(java.base@11/ProtectionDomain.java:95)
	at java.awt.EventQueue$5.run(java.desktop@11/EventQueue.java:745)
	at java.awt.EventQueue$5.run(java.desktop@11/EventQueue.java:743)
	at java.security.AccessController.doPrivileged(java.base@11/Native 
Method)
	at 
java.security.ProtectionDomain$JavaSecurityAccessImpl.doIntersectionPrivilege(java.base@11/ProtectionDomain.java:85)
	at 
java.awt.EventQueue.dispatchEvent(java.desktop@11/EventQueue.java:742)
	at 
java.awt.EventDispatchThread.pumpOneEventForFilters(java.desktop@11/EventDispatchThread.java:203)
	at 
java.awt.EventDispatchThread.pumpEventsForFilter(java.desktop@11/EventDispatchThread.java:124)
	at 
java.awt.EventDispatchThread.pumpEventsForHierarchy(java.desktop@11/EventDispatchThread.java:113)
	at 
java.awt.EventDispatchThread.pumpEvents(java.desktop@11/EventDispatchThread.java:109)
	at 
java.awt.EventDispatchThread.pumpEvents(java.desktop@11/EventDispatchThread.java:101)
	at 
java.awt.EventDispatchThread.run(java.desktop@11/EventDispatchThread.java:90)
> 
> Felix
> 
> Am 14. März 2022 13:40:46 MEZ schrieb Vladimir Sitnikov
> <si...@gmail.com>:
>>> When i clique to display the resultat data (html boy) the JMeter is
>>> very slow to show the page.
>>> I need to wait 4 sec to 8 sec between click and the http sampler and
>>> the display in text format.
>> 
>> Vincent, do you think you could create a reproducer for the issue? 
>> (e.g.
>> share HTML contents)
>> Do you think you could gather thread dumps (e.g. jstack <jmeter_pid>) 
>> while
>> clicking the "view results" tab?
>> 
>> Vladimir

Re: Slow "view results in tree" in 5.5 with Java11 (was [VOTE] Release JMeter 5.5 RC1)

Posted by Felix Schumacher <fe...@internetallee.de>.
I think I can reproduce it. I sampled a biggish page. It recorded three sub samples. Two redirects and the actual page.
Clicking on the main sample takes one or two seconds. Changing to the redirect is fast, but changing back to the main sample or the sub sample with the page is incredibly slow.

Gui is not responding, as the awt thread is calculating the preferred view size and is almost all the time in sun.font.SunLayoutEngine.shape.

Felix 

Am 14. März 2022 13:40:46 MEZ schrieb Vladimir Sitnikov <si...@gmail.com>:
>>When i clique to display the resultat data (html boy) the JMeter is
>>very slow to show the page.
>>I need to wait 4 sec to 8 sec between click and the http sampler and
>>the display in text format.
>
>Vincent, do you think you could create a reproducer for the issue? (e.g.
>share HTML contents)
>Do you think you could gather thread dumps (e.g. jstack <jmeter_pid>) while
>clicking the "view results" tab?
>
>Vladimir